use bevy::{prelude::*, window::PrimaryWindow};

pub struct Plugin;
impl bevy::prelude::Plugin for Plugin {
    fn build(&self, app: &mut App) {
        app.add_systems(Startup, setup)
            .add_systems(Update, move_cam);
    }
}

fn setup(mut cmds: Commands, window: Query<&Window>) {
    let zoom = 2./window.single().width().min(window.single().height());
    cmds.spawn((
        Camera2d,
        Transform::from_scale(Vec3::new(zoom, zoom, 1.))
    ));
}

fn move_cam(
    mut cam: Query<&mut Transform, With<Camera2d>>,
    mouse_buttons: Res<ButtonInput<MouseButton>>,
    mut mouse_events: EventReader<CursorMoved>,
    window: Query<&Window, With<PrimaryWindow>>
) {
    let window = window.single();
    if mouse_buttons.pressed(MouseButton::Left) && !mouse_buttons.just_pressed(MouseButton::Left) {
        for ev in mouse_events.read() {
            if let Some(delta) = ev.delta {
                let mut cam = cam.single_mut();
                cam.translation.x -= delta.x/window.width();
                cam.translation.y += delta.y/window.height();
            }
        }
    }
}